@@ -132,4 +132,13 @@ is_ambiorix <- function(){
 
 assertthat::on_failure(is_ambiorix) <- function(call, env){
   stop("Not an ambiorix app, see `ambiorix.generator` package", call. = FALSE)
+}
+
+# check that it is a leprechaun package
+is_leprechaun <- function(){
+  fs::file_exists(".leprechaun")
+}
+
+assertthat::on_failure(is_leprechaun) <- function(call, env){
+  stop("Not a leprechaun app, see `leprechaun::scaffold_leprechaun`", call. = FALSE)
 }
\ No newline at end of file
