@@ -48,7 +48,7 @@ scaffold_golem <- function(react = FALSE, vue = FALSE, use_cdn = TRUE, edit = in
   engine_init()
 
   # install dependencies
-  webpack_install()
+  core_deps_install()
 
   # edit package.json
   engine_add_scripts()
