@@ -16,6 +16,8 @@ test_that("Yarn", {
 	engine_set("npm")
 	expect_error(yarn_add("sth"))
 	engine_set("yarn")
+	expect_null(engine_which())
+	expect_error(yarn_remove())
 
   # keep working directory
   wd <- getwd()
@@ -25,6 +27,7 @@ test_that("Yarn", {
   setwd(pkg)
   expect_output(scaffold_golem(edit = FALSE))
 	expect_message(engine_yarn_set())
+	expect_is(engine_which(), "character")
 	expect_message(yarn_version())
 	expect_message(yarn_add("browserify"))
 	yarn_install()
@@ -33,8 +36,11 @@ test_that("Yarn", {
 	expect_message(yarn_console())
   expect_message(bundle_prod())
 	expect_message(use_loader_style())
-	expect_message(use_loader_eslint())
   expect_message(add_plugin_eslint())
+	expect_invisible(engine_get())
+	yarn_outdated()
+	yarn_clean()
+	set_yarn("")
   setwd(wd)
   delete_tmp_package(pkg)
 })
